Class: Guts::ApplicationController Abstract
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- Guts::ApplicationController
- Includes:
- MultisiteConcern, SessionConcern
- Defined in:
- app/controllers/guts/application_controller.rb
Overview
This class is abstract.
Main inherited controller class
Direct Known Subclasses
CategoriesController, ContentsController, GroupsController, IndexController, MediaController, MetafieldsController, NavigationItemsController, NavigationsController, OptionsController, PermissionsController, SessionsController, SitesController, TypesController, UsersController
Instance Method Summary collapse
-
#current_ability ⇒ Class
Used by CanCanCan for getting the current abilities of the current user.
Methods included from MultisiteConcern
#current_site, #with_current_site
Instance Method Details
#current_ability ⇒ Class
Used by CanCanCan for getting the current abilities of the current user
19 20 21 |
# File 'app/controllers/guts/application_controller.rb', line 19 def current_ability @current_ability ||= Guts::Ability.new current_user end |