Class: Guts::User
- Inherits:
-
ApplicationRecord
- Object
- ActiveRecord::Base
- ApplicationRecord
- Guts::User
- Includes:
- GrantedConcern
- Defined in:
- app/models/guts/user.rb
Overview
User model
Constant Summary collapse
- VALID_EMAIL_REGEX =
Regex to test email against for validation
/\A[\w+\-.]+@[a-z\d\-.]+\.[a-z]+\z/i
Instance Method Summary collapse
-
#email=(email) ⇒ String
Setter override for email to downcase and strip email before database.
Instance Method Details
#email=(email) ⇒ String
Setter override for email to downcase and strip email before database
32 33 34 |
# File 'app/models/guts/user.rb', line 32 def email=(email) self[:email] = email.downcase.strip end |